"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  HighlightPopover: () => HighlightPopover,
  useHighlightPopover: () => useHighlightPopover
});
module.exports = __toCommonJS(src_exports);

// src/HighlightPopover.tsx
var import_react = require("react");
var import_jsx_runtime = require("react/jsx-runtime");
var HighlightPopoverContext = (0, import_react.createContext)(null);
function useHighlightPopover() {
  const context = (0, import_react.useContext)(HighlightPopoverContext);
  if (!context) {
    throw new Error(
      "useHighlightPopover must be used within a HighlightPopover"
    );
  }
  return context;
}
function HighlightPopover({
  children,
  renderPopover,
  className = "",
  offset = { x: 0, y: 0 },
  zIndex = 40,
  minSelectionLength = 1,
  onSelectionStart,
  onSelectionEnd,
  onPopoverShow,
  onPopoverHide
}) {
  const [showPopover, setShowPopover] = (0, import_react.useState)(false);
  const [popoverPosition, setPopoverPosition] = (0, import_react.useState)({
    top: 0,
    left: 0
  });
  const [currentSelection, setCurrentSelection] = (0, import_react.useState)("");
  const containerRef = (0, import_react.useRef)(null);
  const isSelectionWithinContainer = (0, import_react.useCallback)((selection) => {
    if (!containerRef.current) return false;
    for (let i = 0; i < selection.rangeCount; i++) {
      const range = selection.getRangeAt(i);
      if (!containerRef.current.contains(range.startContainer) || !containerRef.current.contains(range.endContainer)) {
        return false;
      }
    }
    return true;
  }, []);
  const handleSelection = (0, import_react.useCallback)(() => {
    requestAnimationFrame(() => {
      if (!containerRef.current) return;
      const selection = window.getSelection();
      if (selection && selection.toString().trim().length >= minSelectionLength && isSelectionWithinContainer(selection)) {
        onSelectionStart?.();
        const range = selection.getRangeAt(0);
        const rect = range.getBoundingClientRect();
        const containerRect = containerRef.current.getBoundingClientRect();
        const top = rect.bottom - containerRect.top - (offset && (offset.y ?? 0));
        const left = rect.left - containerRect.left + rect.width / 2 + (offset && (offset.x ?? 0));
        setPopoverPosition({ top, left });
        setCurrentSelection(selection.toString());
        setShowPopover(true);
        onPopoverShow?.();
        onSelectionEnd?.(selection.toString());
      } else {
        setShowPopover(false);
        onPopoverHide?.();
      }
    });
  }, [
    isSelectionWithinContainer,
    minSelectionLength,
    offset,
    onSelectionStart,
    onSelectionEnd,
    onPopoverShow,
    onPopoverHide
  ]);
  (0, import_react.useEffect)(() => {
    document.addEventListener("selectionchange", handleSelection);
    return () => {
      document.removeEventListener("selectionchange", handleSelection);
    };
  }, [handleSelection]);
  (0, import_react.useEffect)(() => {
    const handleClickOutside = (event) => {
      if (containerRef.current && !containerRef.current.contains(event.target)) {
        setShowPopover(false);
        onPopoverHide?.();
      }
    };
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, [onPopoverHide]);
  const contextValue = {
    showPopover,
    setShowPopover,
    popoverPosition,
    currentSelection,
    setCurrentSelection
  };
  const popoverStyle = (0, import_react.useMemo)(
    () => ({
      zIndex,
      width: "max-content",
      position: "absolute",
      transform: "translateX(-50%)",
      top: `${popoverPosition.top}px`,
      left: `${popoverPosition.left}px`
    }),
    [zIndex, popoverPosition.top, popoverPosition.left]
  );
  return /* @__PURE__ */ (0, import_jsx_runtime.jsx)(HighlightPopoverContext.Provider, { value: contextValue, children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)(
    "div",
    {
      ref: containerRef,
      style: { position: "relative" },
      className,
      children: [
        children,
        showPopover && /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { style: popoverStyle, role: "tooltip", "aira-live": "polite", children: renderPopover({
          position: popoverPosition,
          selection: currentSelection
        }) })
      ]
    }
  ) });
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  HighlightPopover,
  useHighlightPopover
});
