import * as react_jsx_runtime from 'react/jsx-runtime';
import React from 'react';

/**
 * Represents the position of the popover.
 */
interface Position {
    /** The top position of the popover in pixels. */
    top: number;
    /** The left position of the popover in pixels. */
    left: number;
}
/**
 * Props for the HighlightPopover component.
 */
interface HighlightPopoverProps {
    /** The content where text selection will trigger the popover. */
    children: React.ReactNode;
    /** Function to render the popover component. */
    renderPopover: (props: {
        position: Position;
        selection: string;
    }) => React.ReactNode;
    /** Additional CSS class for the wrapper element. */
    className?: string;
    /** Offset for adjusting popover position. */
    offset?: {
        x?: number;
        y?: number;
    };
    /** The z-index of the popover. */
    zIndex?: number;
    /** Minimum length of text selection to trigger the popover. */
    minSelectionLength?: number;
    /** Callback fired when text selection starts. */
    onSelectionStart?: () => void;
    /** Callback fired when text selection ends. */
    onSelectionEnd?: (selection: string) => void;
    /** Callback fired when the popover is shown. */
    onPopoverShow?: () => void;
    /** Callback fired when the popover is hidden. */
    onPopoverHide?: () => void;
}
/**
 * Context type for the HighlightPopover.
 */
interface HighlightPopoverContextType {
    /** Indicates whether the popover is currently visible. */
    showPopover: boolean;
    /** Function to manually control popover visibility. */
    setShowPopover: React.Dispatch<React.SetStateAction<boolean>>;
    /** Current position of the popover. */
    popoverPosition: Position;
    /** Currently selected text. */
    currentSelection: string;
    /** Function to manually set the current selection. */
    setCurrentSelection: React.Dispatch<React.SetStateAction<string>>;
}
/**
 * Hook to access the HighlightPopover context.
 * @returns The HighlightPopover context value.
 * @throws Error if used outside of a HighlightPopover component.
 */
declare function useHighlightPopover(): HighlightPopoverContextType;
/**
 * HighlightPopover component for creating popovers on text selection within this container.
 */
declare function HighlightPopover({ children, renderPopover, className, offset, zIndex, minSelectionLength, onSelectionStart, onSelectionEnd, onPopoverShow, onPopoverHide, }: HighlightPopoverProps): react_jsx_runtime.JSX.Element;

export { HighlightPopover, useHighlightPopover };
